@@ -6,4 +6,4 @@ export let htmlIntro = `<p>Welcome to Peek.</p>
                 <li>View switching instructions</li>
                 <li>Receive instructions from the control room</li>
                 <li>And field confirm field switching operations</li>
-            </ul>`;
\ No newline at end of file
+            </ul>`
\ No newline at end of file
